pub fn handle_bridge_command(
cmd: BridgeCommand,
pool: &PagePool,
) -> BridgeResponseExpand description
Process a single bridge command by dispatching to the appropriate page in the pool.
pub fn handle_bridge_command(
cmd: BridgeCommand,
pool: &PagePool,
) -> BridgeResponseProcess a single bridge command by dispatching to the appropriate page in the pool.