pub struct AutoCloseWorker { /* private fields */ }Expand description
RAII guard that terminates a Worker when dropped.
Created by BaoWebViewState::track_worker_with_guard. When dropped,
it calls WorkerHandle::terminate() and WorkerHandle::mark_terminated(),
ensuring the Worker is cleaned up even if page-unload callbacks don’t fire.
@trace REQ-BRW-004 [entity:Worker] [criterion:10]
Implementations
Sourceimpl AutoCloseWorker
impl AutoCloseWorker
Sourcepub fn new(handle: WorkerHandle) -> Self
pub fn new(handle: WorkerHandle) -> Self
Create a new AutoCloseWorker guard for the given WorkerHandle.
@trace REQ-BRW-004 [entity:Worker] [criterion:10]
Sourcepub fn lifecycle_state(&self) -> WorkerLifecycleState
pub fn lifecycle_state(&self) -> WorkerLifecycleState
Get the Worker’s lifecycle state.
@trace REQ-BRW-004 [entity:Worker] [criterion:18]
Sourcepub fn terminate_via(&mut self, path: WorkerTeardownPath)
pub fn terminate_via(&mut self, path: WorkerTeardownPath)
Signal the Worker to terminate via the given teardown path. Only transitions from Running → Closing if not already closing.
@trace REQ-BRW-004 [entity:Worker] [criterion:4] [criterion:10]
Sourcepub fn handle(&self) -> &WorkerHandle
pub fn handle(&self) -> &WorkerHandle
Access the underlying WorkerHandle.